embed

package
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 9, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var K3dConfig string

Embedded file systems Note: embed paths are relative to this file's directory (internal/embed/)

Functions

func CopyDefaults

func CopyDefaults(destDir string) error

CopyDefaults recursively copies all embedded infrastructure manifests to the destination directory

func CopyNetwork added in v0.2.3

func CopyNetwork(networkName, destDir string) error

CopyNetwork recursively copies an embedded network to the destination directory

func GetAvailableNetworks added in v0.2.3

func GetAvailableNetworks() ([]string, error)

GetAvailableNetworks returns a list of all embedded network names

func ReadEmbeddedNetworkFile added in v0.2.3

func ReadEmbeddedNetworkFile(networkName, filename string) ([]byte, error)

ReadEmbeddedNetworkFile reads a file from an embedded network

Types

This section is empty.

Jump to