embed

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var HelmfileTemplate string
var K3dConfig string

Embedded file systems Note: embed paths are relative to this file's directory (internal/embed/)

Functions

func CopyCharts

func CopyCharts(destDir string) error

CopyCharts recursively copies all embedded charts to the destination directory

func CopyDefaults

func CopyDefaults(destDir string) error

CopyDefaults recursively copies all embedded default manifests to the destination directory

Types

This section is empty.

Jump to